(defgroup babylon nil
  "Emacs mode interface to babylon translator system"
  :group 'applications)

(defcustom babylon-binary "/usr/local/bin/babylon"
  "Path to the binary of babylon. This must be an absolute file name."
  :type '(choice string 
		 (const "/usr/local/bin/babylon")
		 (const "/usr/bin/babylon")
		 (const "/home/mquinson/src/babytrans-0.3.7/src/mt/babylon"))
  :group 'babylon)

(defcustom babylon-definition-dictionary "/usr/local/lib/babytrans/english.dic"
  "*Path to the dictionary of definitions. This must be an absolute file name."
  :type '(choice file 
		 (const "/usr/local/lib/babytrans/english.dic")
		 (const "/usr/lib/babytrans/english.dic"))
  :group 'babylon)

(defcustom babylon-dictionary "/usr/local/lib/babytrans/EngtoFre.dic"
  "*Path to dictionary of translations. This must be an absolute file name."
  :type '(choice file 
		 (const "/usr/local/lib/babytrans/EngtoFre.dic")
		 (const "/usr/lib/babytrans/EngtoFre.dic"))
  :type 'file
  :group 'babylon)

;--[ babylon: main entry point ]---------------------------------------------------------------------
(defun babylon (word)
  "Translates the given word. In interactive mode, asks for a word to translate"
  (interactive
   (setq word 
       (list (read-from-minibuffer "Word to translate: "
				   babylon-word nil nil
				   '(babylon-word-history . 1)))
       ))
  (setq babylon-word word)
  (babylon-internal babylon-word))

(defun babylon-internal (word)
  "Opens a buffer containing the translation of the given word"
  (let (outbuf)
    (save-excursion
      (setq outbuf
	    (get-buffer-create
	     (funcall (function (lambda (mode-name) "*translation*"))
		      mode-name)))
      (set-buffer outbuf)
      (setq buffer-read-only nil)
      (buffer-disable-undo (current-buffer))
      (erase-buffer)
      (buffer-enable-undo (current-buffer))
      (setq outwin (display-buffer outbuf))
      (message "Translating `%s'..." word)
      (call-process babylon-binary nil t t  
		    babylon-definition-dictionary babylon-dictionary word)
      (setq buffer-read-only t)
      (set-buffer-modified-p nil)
      )))

(defun babylon-word ()
  "Translate the word under or before the cursor."
  (interactive)
  (save-excursion
    (forward-word -1)
    (setq beg (point))
    (forward-word 1)
    (setq end (point))
    (setq word (buffer-substring beg end))
    (babylon word)))

(global-set-key "\M-?" 'babylon-word)
(provide 'babylon)
